import request from '@/utils/request'
import { status } from 'nprogress'

// 查询设备信息列表
export function listDeviceInfo(query) {
  return request({
    url: '/watch-api/device/myList',
    method: 'get',
    params: query
  })
}

// 查询设备信息详细
export function getDeviceInfo(deviceId) {
  return request({
    url: '/watch-api/device/' + deviceId,
    method: 'get'
  })
}

// 查询当月新增设备
export function getAddCountByMonth() {
  return request({
    url: '/watch-api/device/getAddCountByMonth',
    method: 'get'
  })
}

// 根据设备编号查询设备信息详细
export function getDeviceInfoByNumber(data) {
  return request({
    url: '/watch-api/device/getByNumber',
    method: 'get',
    params: data
  })
}

// 新增设备信息
export function addDeviceInfo(data) {
  return request({
    url: '/watch-api/device',
    method: 'post',
    data: data
  })
}

// 修改设备信息
export function updateDeviceInfo(data) {
  return request({
    url: '/watch-api/device',
    method: 'put',
    data: data
  })
}

// 删除设备信息
export function delDeviceInfo(deviceId) {
  return request({
    url: '/watch-api/device/' + deviceId,
    method: 'delete'
  })
}

// 导出设备信息
export function exportDeviceInfo(query) {
  return request({
    url: '/watch-api/device/export',
    method: 'get',
    params: query
  })
}

  // 查询用户信息
export function getUser(data) {
  return request({
    url: '/watch-api/device/set/up/getUserInfo',
    method: 'get',
    params:data
  })
}

// 获取心率数据
export function getHeartRateData(deviceId) {
  return request({
    url: `/watch-api/watch/heart/rate/${deviceId}`,
    method: 'get'
  })
}

// 获取设备基本数据
export function getWatchData(deviceId) {
  return request({
    url: `/watch-api/watch/basic/info/${deviceId}`,
    method: 'get'
  })
}

// 根据时间获取心率数据
export function queryByDate(date,deviceId) {
  return request({
    url: `/watch-api/watch/heart/rate/queryByDate`,
    method: 'get',
    params: { date,deviceId } 
  })
}

//exportHeartDate导出
export function exportHeartDate(date,deviceId) {
  return request({
    url: `/watch-api/watch/heart/rate/exportByDate`,
    method: 'get',
    params: { date,deviceId } 
  })
}

//获取运动信息
export function querySportData(date,deviceId) {
  return request({
    url: `/watch-api/watch/sport/data/queryByDateAndDeviceId`,
    method: 'get',
    params: { date,deviceId } 
  })
}

//导出运动信息
export function exportSporttDate(date,deviceId) {
  return request({
    url: `/watch-api/watch/sport/data/exportByDate`,
    method: 'get',
    params: { date,deviceId } 
  })
}

// 根据时间获取脉搏数据
export function queryPulseDate(date,deviceId) {
  return request({
    url: `/watch-api/watch/continuous/spo2/data/queryPulseRate`,
    method: 'get',
    params: { date,deviceId } 
  })
}

// 根据时间获取血糖数据
export function queryGlucoseDate(date,deviceId) {
  return request({
    url: `/watch-api/watch/blood/glucose/queryByDateAndDeviceId`,
    method: 'get',
    params: { date,deviceId } 
  })
}

// 根据时间获取房颤数据
export function queryAfDate(date,deviceId) {
  return request({
    url: `/watch-api/watch/rri/data/queryByDateAndDeviceId`,
    method: 'get',
    params: { date,deviceId } 
  })
}

// 根据时间获取血压数据
export function queryPressure(date,deviceId) {
  return request({
    url: `/watch-api/watch/blood/pressure/queryByDateAndDeviceId`,
    method: 'get',
    params: { date,deviceId } 
  })
}

// 根据时间获取温度数据
export function queryTemperature(date,deviceId) {
  return request({
    url: `/watch-api/watch/temperature/queryByDateAndDeviceId`,
    method: 'get',
    params: { date,deviceId } 
  })
}

// 根据时间获取概况数据
export function queryOverview(date,deviceId) {
  return request({
    url: `/watch-api/watch/basic/info/queryOverview`,
    method: 'get',
    params: { date,deviceId } 
  })
}

// 根据时间获取血氧数据
export function querySpo2(date,deviceId) {
  return request({
    url: `/watch-api/watch/spo2/data/queryByDateAndDeviceId`,
    method: 'get',
    params: { date,deviceId } 
  })
}

// 根据时间获取睡眠数据
export function querySleep(date,deviceId) {
  return request({
    url: `/watch-api/watch/sleep/data/queryByDateAndDeviceId`,
    method: 'get',
    params: { date,deviceId } 
  })
}

// 获取预警数据
export function queryAlarm(status) {
  return request({
    url: `/watch-api/watch/alarm/queryByStatus`,
    method: 'get',
    params: { status } 
    
  })
}

// 获取预警数据(分页版本)
export function queryPageAlarm(query) {
  return request({
    url: `/watch-api/watch/alarm/queryPageByStatus`,
    method: 'get',
    params: query
    
  })
}

// 设置已读
export function setStatus(ids) {
  return request({
    url: '/watch-api/watch/alarm/setStatusById',
    method: 'post',
    data: ids
  })
}

//获取一天的路线
export function queryGnss(data) {
  return request({
      url: '/watch-api/watch/basic/info/queryGnssByDateAndDeviceId',
      method: 'get',
      params:data
  })
}


//获取一天的路线
export function exportSleeptDate(data) {
  return request({
      url: '/watch-api/watch/sleep/data/exportByDate',
      method: 'get',
      params:data
  })
}

//获取血酮数据
export function queryBkData(data) {
  return request({
      url: '/watch-api/watch/third/bk/queryByDateAndDeviceId',
      method: 'get',
      params:data
  })
}

//获取尿酸数据
export function queryUaData(data) {
  return request({
      url: '/watch-api/watch/third/ua/queryByDateAndDeviceId',
      method: 'get',
      params:data
  })
}

//获最新健康数据
export function queryLastHealthData(data) {
  return request({
      url: '/watch-api/device/queryLastWatchData',
      method: 'get',
      params:data
  })
}


//获最联系人
export function querySos(data) {
  return request({
      url: '/watch-api/device/querySos',
      method: 'get',
      params:data
  })
}

//查询某个时间段心率数据 分页
export function queryPageByDate(data) {
  return request({
      url: '/watch-api/watch/heart/rate/page',
      method: 'get',
      params:data
  })
}

//查询某个时间段的分类数据 分页
export function querySportPageByDate(data) {
  return request({
      url: '/watch-api/watch/sport/data/queryPageByDataAndDeviceId',
      method: 'get',
      params:data
  })
}

//查询某个时间段的睡眠数据 分页
export function querySleepPageByDate(data) {
  return request({
      url: '/watch-api/watch/sleep/data/page',
      method: 'get',
      params:data
  })
}

//查询某个时间段的地理数据 分页
export function queryLocPageByDate(data) {
  return request({
      url: '/watch-api/watch/basic/info/page',
      method: 'get',
      params:data
  })
}

//查询某个时间段的温度数据 分页
export function queryTemperaturePageByDate(data) {
  return request({
      url: '/watch-api/watch/temperature/page',
      method: 'get',
      params:data
  })
}

//查询某个时间段的温度数据 分页
export function queryBOPageByDate(data) {
  return request({
      url: '/watch-api/watch/continuous/spo2/data/queryPageByDateAndDeviceId',
      method: 'get',
      params:data
  })
}